@@ -27,9 +27,7 @@ from .const import CAST_TYPE_CHROMECAST, SERVICE_TYPE_HOST
 from .controllers.media import STREAM_TYPE_BUFFERED  # noqa: F401
 from .models import CastInfo
 
-__all__ = ("__version__", "__version_info__", "get_chromecasts", "Chromecast")
-__version_info__ = ("0", "7", "6")
-__version__ = ".".join(__version_info__)
+__all__ = ("get_chromecasts", "Chromecast")
 
 IDLE_APP_ID = "E8C28D3C"
 IGNORE_CEC = []
@@ -292,6 +290,7 @@ class Chromecast:
         self.set_volume_muted = receiver_controller.set_volume_muted
         self.play_media = self.socket_client.media_controller.play_media
         self.register_handler = self.socket_client.register_handler
+        self.unregister_handler = self.socket_client.unregister_handler
         self.register_status_listener = receiver_controller.register_status_listener
         self.register_launch_error_listener = (
             receiver_controller.register_launch_error_listener
