@@ -10,8 +10,8 @@ APP_YOUTUBE = "233637DE"
 APP_MEDIA_RECEIVER = "CC1AD845"
 APP_PLEX = "06ee44ee-e7e3-4249-83b6-f5d0b6f07f34_1"
 APP_DASHCAST = "84912283"
-APP_SPOTIFY = "CC32E753"
-APP_HOME_ASSISTANT = "B12CE3CA"
+APP_HOMEASSISTANT_LOVELACE = "A078F6B0"
+APP_HOMEASSISTANT_MEDIA = "B45F4572"
 APP_SUPLA = "A41B766D"
 APP_YLEAREENA = "A9BCCB7C"
 APP_BUBBLEUPNP = "3927FA74"
@@ -24,7 +24,8 @@ def get_possible_app_ids():
 
     try:
         req = requests.get(
-            "https://clients3.google.com/cast/chromecast/device/baseconfig"
+            "https://clients3.google.com/cast/chromecast/device/baseconfig",
+            timeout=10,
         )
         data = json.loads(req.text[4:])
 
@@ -39,9 +40,8 @@ def get_app_config(app_id):
     """Get specific configuration for 'app_id'."""
     try:
         req = requests.get(
-            ("https://clients3.google.com/cast/chromecast/device/app?a={}").format(
-                app_id
-            )
+            f"https://clients3.google.com/cast/chromecast/device/app?a={app_id}",
+            timeout=10,
         )
 
         return json.loads(req.text[4:]) if req.status_code == 200 else {}
