@@ -1,12 +1,13 @@
 """ Choose a controller and quick play """
 
-from .controllers.youtube import YouTubeController
-from .controllers.supla import SuplaController
-from .controllers.yleareena import YleAreenaController
-from .controllers.spotify import SpotifyController
-from .controllers.bubbleupnp import BubbleUPNPController
 from .controllers.bbciplayer import BbcIplayerController
 from .controllers.bbcsounds import BbcSoundsController
+from .controllers.bubbleupnp import BubbleUPNPController
+from .controllers.homeassistant_media import HomeAssistantMediaController
+from .controllers.media import DefaultMediaReceiverController
+from .controllers.supla import SuplaController
+from .controllers.yleareena import YleAreenaController
+from .controllers.youtube import YouTubeController
 
 
 def quick_play(cast, app_name, data):
@@ -52,23 +53,27 @@ def quick_play(cast, app_name, data):
             "BUFFERED" or "LIVE"
     """
 
-    if app_name == "youtube":
-        controller = YouTubeController()
+    if app_name == "bbciplayer":
+        controller = BbcIplayerController()
+    elif app_name == "bbcsounds":
+        controller = BbcSoundsController()
+    elif app_name == "bubbleupnp":
+        controller = BubbleUPNPController()
+    elif app_name == "default_media_receiver":
+        controller = DefaultMediaReceiverController()
+    elif app_name == "homeassistant_media":
+        controller = HomeAssistantMediaController()
     elif app_name == "supla":
         controller = SuplaController()
     elif app_name == "yleareena":
         controller = YleAreenaController()
-    elif app_name == "spotify":
-        controller = SpotifyController()
-    elif app_name == "bubbleupnp":
-        controller = BubbleUPNPController()
-    elif app_name == "bbciplayer":
-        controller = BbcIplayerController()
-    elif app_name == "bbcsounds":
-        controller = BbcSoundsController()
+    elif app_name == "youtube":
+        controller = YouTubeController()
     else:
         raise NotImplementedError()
 
     cast.register_handler(controller)
 
     controller.quick_play(**data)
+
+    cast.unregister_handler(controller)
